## Descripción del proyecto

La siguiente proyecto consiste en una clase que permite el coloreado y el formateo de la salida estándar para la terminal en lenguaje **python**.

A su vez, la clase es polimórfica y se puede instanciar indicando los títulos de la cabecera para generar tablas de datos que se formtearán adaptándose al tamaño de los campos.

Uso de la clase y ejemplos:    
[https://github.com/gmolino/colorin](https://github.com/gmolino/colorin)

## Versiones

##### 0.0.1

* Primer commit con los métodos descritos en el proyecto
